==> aliyun-java-sdk-vod-2.15.2-sources.jar: com/aliyuncs/vod/transform/v20170321/UpdateAttachedMediaInfosResponseUnmarshaller.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.vod.transform.v20170321;

import java.util.ArrayList;
import java.util.List;

import com.aliyuncs.vod.model.v20170321.UpdateAttachedMediaInfosResponse;
import com.aliyuncs.transform.UnmarshallerContext;


public class UpdateAttachedMediaInfosResponseUnmarshaller {

	public static UpdateAttachedMediaInfosResponse unmarshall(UpdateAttachedMediaInfosResponse updateAttachedMediaInfosResponse, UnmarshallerContext context) {
		
		updateAttachedMediaInfosResponse.setRequestId(context.stringValue("UpdateAttachedMediaInfosResponse.RequestId"));

		List<String> nonExistMediaIds = new ArrayList<String>();
		for (int i = 0; i < context.lengthValue("UpdateAttachedMediaInfosResponse.NonExistMediaIds.Length"); i++) {
			nonExistMediaIds.add(context.stringValue("UpdateAttachedMediaInfosResponse.NonExistMediaIds["+ i +"]"));
		}
		updateAttachedMediaInfosResponse.setNonExistMediaIds(nonExistMediaIds);
	 
	 	return updateAttachedMediaInfosResponse;
	}
}

==> aliyun-java-sdk-vod-2.15.10-sources.jar: com/aliyuncs/vod/transform/v20170321/UpdateAttachedMediaInfosResponseUnmarshaller.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.vod.transform.v20170321;

import java.util.ArrayList;
import java.util.List;

import com.aliyuncs.vod.model.v20170321.UpdateAttachedMediaInfosResponse;
import com.aliyuncs.transform.UnmarshallerContext;


public class UpdateAttachedMediaInfosResponseUnmarshaller {

	public static UpdateAttachedMediaInfosResponse unmarshall(UpdateAttachedMediaInfosResponse updateAttachedMediaInfosResponse, UnmarshallerContext _ctx) {
		
		updateAttachedMediaInfosResponse.setRequestId(_ctx.stringValue("UpdateAttachedMediaInfosResponse.RequestId"));

		List<String> nonExistMediaIds = new ArrayList<String>();
		for (int i = 0; i < _ctx.lengthValue("UpdateAttachedMediaInfosResponse.NonExistMediaIds.Length"); i++) {
			nonExistMediaIds.add(_ctx.stringValue("UpdateAttachedMediaInfosResponse.NonExistMediaIds["+ i +"]"));
		}
		updateAttachedMediaInfosResponse.setNonExistMediaIds(nonExistMediaIds);
	 
	 	return updateAttachedMediaInfosResponse;
	}
}
